drama.shaders = {};
drama.shaders["blacknwhitemask"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform lowp sampler2D samplerBack;\nuniform mediump vec2 destStart;\nuniform mediump vec2 destEnd;\nuniform lowp float threshold;\n\nvoid main(void)\n{	lowp float fronta = texture2D(samplerFront, vTex).a;\n	\n	mediump vec2 tex = (vTex - srcStart) / (srcEnd - srcStart);\n	lowp vec4 back = texture2D(samplerBack, mix(destStart, destEnd, tex));	lowp float gray = back.r * 0.299 + back.g * 0.587 + back.b * 0.114;	if (gray < threshold)\n		gl_FragColor = mix(back, vec4(0.0, 0.0, 0.0, back.a), fronta);\n	else\n		gl_FragColor = mix(back, vec4(back.a, back.a, back.a, back.a), fronta);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["threshold",0,1]]
};

drama.shaders["grayscale"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp float intensity;\n\nvoid main(void)\n{	lowp vec4 front = texture2D(samplerFront, vTex);	lowp float gray = front.r * 0.299 + front.g * 0.587 + front.b * 0.114;	gl_FragColor = mix(front, vec4(gray, gray, gray, front.a), intensity);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["intensity",0,1]]
};

drama.shaders["grayscalemask"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform lowp sampler2D samplerBack;\nuniform mediump vec2 destStart;\nuniform mediump vec2 destEnd;\nuniform lowp float threshold;\n\nvoid main(void)\n{	lowp float fronta = texture2D(samplerFront, vTex).a;\n	\n	mediump vec2 tex = (vTex - srcStart) / (srcEnd - srcStart);\n	lowp vec4 back = texture2D(samplerBack, mix(destStart, destEnd, tex));	lowp float gray = back.r * 0.299 + back.g * 0.587 + back.b * 0.114;	gl_FragColor = mix(back, vec4(gray, gray, gray, back.a), fronta);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: []
};

drama.shaders["lens2"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform mediump vec2 srcOriginStart;\nuniform mediump vec2 srcOriginEnd;\nuniform lowp sampler2D samplerBack;\nuniform mediump vec2 destStart;\nuniform mediump vec2 destEnd;\nuniform mediump float magnification;\n\nvoid main(void)\n{	\n	lowp vec4 front = texture2D(samplerFront, vTex);\n	mediump vec2 tex = (vTex - srcStart) / (srcEnd - srcStart);	mediump float zoomFactor = (0.5 - (front.r * 0.299 + front.g * 0.587 + front.b * 0.114)) * front.a * magnification;\n	mediump vec2 center = (srcOriginStart + srcOriginEnd) / 2.0;\n\n	mediump vec2 p = tex;\n	p += (tex - center) * zoomFactor;\n\n	gl_FragColor = texture2D(samplerBack, mix(destStart, destEnd, p));\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: true,
	preservesOpaqueness: false,
	animated: false,
	parameters: [["magnification",0,1]]
};

drama.shaders["noise"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump float seconds;\nuniform lowp float intensity;\nuniform lowp float noiseColor;\n\nvoid main(void)\n{	lowp vec4 front = texture2D(samplerFront, vTex);\n	lowp float a = front.a;\n	\n	if (a != 0.0)\n		front.rgb /= a;\n	\n	mediump float seconds_mod = mod(seconds, 10.0);	mediump vec3 noise = vec3(fract(sin(dot(vTex.xy, vec2(12.9898,78.233)) + seconds_mod) * 43758.5453),\n							  fract(sin(dot(vTex.yx, vec2(12.9898,-78.233)) + seconds_mod) * 43758.5453),\n							  fract(sin(dot(vTex.xy, vec2(-12.9898,-78.233)) + seconds_mod) * 43758.5453));\n	noise = mix(vec3(noise.r), noise, noiseColor);\n	front.rgb += (noise * intensity) - (intensity / 2.0);\n	front.rgb *= a;\n	\n	gl_FragColor = front;\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["intensity",0,1],["noiseColor",0,1]]
};

drama.shaders["tint"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform lowp vec3 tintColor;\n\nvoid main(void)\n{\n	lowp vec4 front = texture2D(samplerFront, vTex);\n	\n	gl_FragColor = front * vec4(tintColor.r, tintColor.g, tintColor.b, 1.0);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["tintColor",0,2]]
};

drama.shaders["warp"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform mediump float seconds;\nuniform mediump vec2 pixelSize;\nuniform mediump float layerScale;\n\nuniform mediump float freqX;\nuniform mediump float freqY;\nuniform mediump float ampX;\nuniform mediump float ampY;\nuniform mediump float speedX;\nuniform mediump float speedY;\n\nvoid main(void)\n{	mediump vec2 srcSize = srcEnd - srcStart;\n	mediump vec2 tex = ((vTex - srcStart) / srcSize);\n	mediump float aspect = pixelSize.y / pixelSize.x;\n	\n	mediump vec2 p = vTex;\n    p.x += (cos(tex.y * freqX / (pixelSize.x * 750.0) + (seconds * speedX)) * ampX * layerScale * pixelSize.x);\n	p.y += (sin(tex.x * freqY * aspect / (pixelSize.y * 750.0) + (seconds * speedY)) * ampY * layerScale * pixelSize.y);\n	\n	p = clamp(p, min(srcStart, srcEnd), max(srcStart, srcEnd));\n	\n	gl_FragColor = texture2D(samplerFront, p);\n}\n",
	extendBoxHorizontal: 30,
	extendBoxVertical: 30,
	crossSampling: false,
	preservesOpaqueness: false,
	animated: true,
	parameters: [["freqX",0,0],["freqY",0,0],["ampX",0,0],["ampY",0,0],["speedX",0,0],["speedY",0,0]]
};

drama.shaders["warpobjectmask"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nuniform mediump vec2 srcStart;\nuniform mediump vec2 srcEnd;\nuniform mediump vec2 srcOriginStart;\nuniform mediump vec2 srcOriginEnd;\nuniform lowp sampler2D samplerBack;\nuniform mediump vec2 destStart;\nuniform mediump vec2 destEnd;\nuniform mediump float seconds;\nuniform mediump vec2 pixelSize;\nuniform mediump float layerScale;\n\nuniform mediump float freqX;\nuniform mediump float freqY;\nuniform mediump float ampX;\nuniform mediump float ampY;\nuniform mediump float speedX;\nuniform mediump float speedY;\n\nvoid main(void)\n{\n	mediump float _2pi = 2.0 * 3.14159265359;\n	\n	lowp float fronta = texture2D(samplerFront, vTex).a;\n	\n	mediump vec2 srcSize = srcEnd - srcStart;\n	mediump vec2 tex = ((vTex - srcStart) / srcSize);	mediump vec2 srcOriginSize = srcOriginEnd - srcOriginStart;\n	mediump vec2 n = ((vTex - srcOriginStart) / srcOriginSize);	mediump vec2 p = mix(destStart, destEnd, tex);\n	p.x += cos(n.y * _2pi * freqY + seconds * speedY * _2pi) * ampY * pixelSize.x * layerScale * fronta;\n	p.y += sin(n.x * _2pi * freqX + seconds * speedX * _2pi) * ampX * pixelSize.y * layerScale * fronta;\n	\n	p = clamp(p, min(destStart, destEnd), max(destStart, destEnd));\n	\n	gl_FragColor = texture2D(samplerBack, p);\n}\n",
	extendBoxHorizontal: 30,
	extendBoxVertical: 30,
	crossSampling: true,
	preservesOpaqueness: false,
	animated: true,
	parameters: [["freqX",0,0],["freqY",0,0],["ampX",0,0],["ampY",0,0],["speedX",0,0],["speedY",0,0]]
};
