const { app, BrowserWindow, Menu, screen} = require('electron');
const path = require('path');
const config = require('./config');
const { createMenu, updateMenu } = require('./menu');

let mainWindow;
global.isFullScreen = false;

process.env.ELECTRON_DISABLE_SECURITY_WARNINGS = true;

if (config.debug.showConfig) {
  console.log(config);
}

const gotTheLock = app.requestSingleInstanceLock();
if (config.singleInstance && !gotTheLock) {
  app.quit();
  return;
}

function createWindow() {
  const { window } = config;
  
  const windowConstConfig = {
    frame: window.frame || !window.framelessFullscreen,
    webPreferences: {
      nodeIntegration: false,
      webSecurity: false,
      allowRunningInsecureContent: true,
      preload: path.join(__dirname, 'preload.js'),
    }
  };

  const finalConfig = { ...window, ...windowConstConfig };
  console.log(finalConfig);

  mainWindow = new BrowserWindow(finalConfig);

  if (!finalConfig.menu) {
    try {
      mainWindow.setMenu(null);
    } catch (e) {
      console.log("Remove menu faild.");
    }
  } else {
    const menu = createMenu();
    Menu.setApplicationMenu(menu);
  }

  const session = mainWindow.webContents.session;
  session.clearStorageData({
    storages: ['cachestorage', 'serviceworkers'],
  }).then(() => {
    console.log('Storage Cleared');
  }).catch((e) => {
    console.log('Clearing cache faild:', e);
  });

  if (window.framelessFullscreen) {
    const bounds = mainWindow.getBounds();
    const display = screen.getDisplayMatching(bounds);
    const { width, height } = display.size;
    const { x, y } = display.bounds;

    mainWindow.setResizable(false);
    mainWindow.setBounds({ x: 0, y: 0, width: width, height: height });
    mainWindow.setAlwaysOnTop(true);
  }

  const gamePath = path.join(app.getAppPath(), 'Data', 'index.html');
  mainWindow.loadFile(gamePath);

  if (config.development.openChromeDevTools) {
    mainWindow.webContents.openDevTools();
  }

  mainWindow.on('closed', () => {
    mainWindow = null;
  });

  mainWindow.on('focus', function (event) {
    mainWindow.webContents.send('message', 'focus');
  });

  mainWindow.on('enter-full-screen', () => {
    global.isFullScreen = true;
    updateMenu();
  });

  // 监听退出全屏事件
  mainWindow.on('leave-full-screen', () => {
    global.isFullScreen = false;
    updateMenu();
  });
}

app.on('second-instance', () => {  
    if (mainWindow) {
      if (mainWindow.isMinimized) {
        mainWindow.restore();
      }
      mainWindow.focus();
    }
});

app.on('ready', createWindow);

app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') {
    app.quit();
  }
});

app.on('activate', () => {
  if (mainWindow === null) {
    createWindow();
  }
});